==> scummvm_2.7.0+dfsg.orig.tar.xz: scummvm-2.7.0+dfsg/engines/wintermute/ad/ad_item.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*
 * This file is based on WME Lite.
 * http://dead-code.org/redir.php?target=wmelite
 * Copyright (c) 2011 Jan Nedoma
 */

#ifndef WINTERMUTE_ADITEM_H
#define WINTERMUTE_ADITEM_H


#include "engines/wintermute/ad/ad_talk_holder.h"

namespace Wintermute {

class AdItem : public AdTalkHolder {
	using Wintermute::AdObject::display;

public:
	bool update() override;
	DECLARE_PERSISTENT(AdItem, AdTalkHolder)
	bool display(int x, int y);
	bool getExtendedFlag(const char *flagName) override;
	bool _inInventory;
	bool _cursorCombined;
	BaseSprite *_spriteHover;
	BaseSprite *_cursorNormal;
	BaseSprite *_cursorHover;
	AdItem(BaseGame *inGame);
	~AdItem() override;
	bool loadFile(const char *filename);
	bool loadBuffer(char *buffer, bool complete = true);

	// scripting interface
	ScValue *scGetProperty(const Common::String &name) override;
	bool scSetProperty(const char *name, ScValue *value) override;
	bool scCallMethod(ScScript *script, ScStack *stack, ScStack *thisStack, const char *name) override;
	const char *scToString() override;
private:
	bool _displayAmount;
	int32 _amount;
	int32 _amountOffsetX;
	int32 _amountOffsetY;
	TTextAlign _amountAlign;
	char *_amountString;
};

} // End of namespace Wintermute

#endif

==> scummvm_2026.1.0+dfsg.orig.tar.xz: scummvm-2026.1.0/engines/wintermute/ad/ad_item.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*
 * This file is based on WME Lite.
 * http://dead-code.org/redir.php?target=wmelite
 * Copyright (c) 2011 Jan Nedoma
 */

#ifndef WINTERMUTE_ADITEM_H
#define WINTERMUTE_ADITEM_H


#include "engines/wintermute/ad/ad_talk_holder.h"

namespace Wintermute {

class AdItem : public AdTalkHolder {
	using Wintermute::AdObject::display;

public:
	bool _displayAmount;
	int32 _amount;
	int32 _amountOffsetX;
	int32 _amountOffsetY;
	TTextAlign _amountAlign;
	char *_amountString;

	bool update() override;
	DECLARE_PERSISTENT(AdItem, AdTalkHolder)
	bool display(int x, int y);
	bool getExtendedFlag(const char *flagName) override;
	bool _inInventory;
	bool _cursorCombined;
	BaseSprite *_spriteHover;
	BaseSprite *_cursorNormal;
	BaseSprite *_cursorHover;
	AdItem(BaseGame *inGame);
	~AdItem() override;
	bool loadFile(const char *filename);
	bool loadBuffer(char *buffer, bool complete = true);

	// scripting interface
	ScValue *scGetProperty(const char *name) override;
	bool scSetProperty(const char *name, ScValue *value) override;
	bool scCallMethod(ScScript *script, ScStack *stack, ScStack *thisStack, const char *name) override;
	const char *scToString() override;
};

} // End of namespace Wintermute

#endif
